@@ -5,6 +5,7 @@ from typing import Iterable, Optional, Tuple
 
 from email_validator import EmailNotValidError, validate_email
 
+from authx.cache import RedisBackend
 from authx.core.config import (
     EMAIL_CONFIRMATION_MAX,
     EMAIL_CONFIRMATION_TIMEOUT,
@@ -14,7 +15,7 @@ from authx.core.config import (
     PASSWORD_RESET_TIMEOUT,
 )
 from authx.core.logger import logger
-from authx.database import MongoDBBackend, RedisBackend
+from authx.database import BaseDBBackend
 
 
 class Base:
@@ -24,7 +25,7 @@ class Base:
 
     def __init__(
         self,
-        database: MongoDBBackend,
+        database: BaseDBBackend,
         cache: RedisBackend,
         callbacks: Iterable,
         access_expiration: int = 60 ** 2 * 6,
@@ -37,7 +38,7 @@ class Base:
             callbacks (Iterable): The callbacks to use.
             access_expiration (int, optional): The expiration time for access tokens. Defaults to 60 * 60 * 6.
         """
-        self._database: Optional[MongoDBBackend] = database
+        self._database: Optional[BaseDBBackend] = database
         self._cache: Optional[RedisBackend] = cache
         self._callbacks = callbacks
         self._access_expiration = access_expiration
@@ -396,10 +397,7 @@ class UsersPasswordMixin(Base):
             Optional[int]: The id for the token.
         """
         id = await self._cache.get(f"users:reset:token:{token_hash}")
-        if id is not None:
-            return int(id)
-        else:
-            return None  # pragma: no cover
+        return int(id) if id is not None else None
 
 
 class UsersManagementMixin(Base):
