@@ -2,12 +2,12 @@ from typing import Iterable, Optional
 
 from aioredis import Redis
 from fastapi import APIRouter, HTTPException, Request
-from motor.motor_asyncio import AsyncIOMotorClient
 
 from authx.api import UsersRepo
+from authx.cache import RedisBackend
 from authx.core.jwt import JWTBackend
 from authx.core.user import User
-from authx.database import MongoDBBackend, RedisBackend
+from authx.database import BaseDBBackend
 from authx.routers import (
     get_admin_router,
     get_auth_router,
@@ -17,7 +17,6 @@ from authx.routers import (
 )
 
 
-# FIXME: Error while using Swagger UI or Redoc
 class authx:
     """Authx is a fastapi application that provides a simple way to authenticate users.
     Using this application, you can easily create a user management system that allows users to register,
@@ -32,7 +31,6 @@ class authx:
         access_expiration: int,
         refresh_expiration: int,
     ) -> None:
-        # TODO: Fix Issue relate to OpenAPI
         self._access_cookie_name = access_cookie_name
         self._refresh_cookie_name = refresh_cookie_name
 
@@ -49,8 +47,7 @@ class authx:
         self._cache_backend.set_client(client)
 
     async def get_user(self, request: Request) -> User:
-        access_token = request.cookies.get(self._access_cookie_name)
-        if access_token:
+        if access_token := request.cookies.get(self._access_cookie_name):
             return await User.create(access_token, self._auth_backend)
         else:
             return User()
@@ -59,15 +56,13 @@ class authx:
         self,
         request: Request,
     ) -> User:
-        access_token = request.cookies.get(self._access_cookie_name)
-        if access_token:
+        if access_token := request.cookies.get(self._access_cookie_name):
             return await User.create(access_token, self._auth_backend)
         else:
             raise HTTPException(401)
 
     async def admin_required(self, request: Request) -> None:
-        access_token = request.cookies.get(self._access_cookie_name)
-        if access_token:
+        if access_token := request.cookies.get(self._access_cookie_name):
             user = await User.create(access_token, self._auth_backend)
             if user.is_admin:
                 return
@@ -88,7 +83,7 @@ class Authentication(authx):
         debug: bool,
         base_url: str,
         site: str,
-        database_name: str,
+        database_backend: BaseDBBackend,
         callbacks: Iterable,
         access_cookie_name: str,
         refresh_cookie_name: str,
@@ -108,7 +103,6 @@ class Authentication(authx):
         self._debug = debug
         self._base_url = base_url
         self._site = site
-        self._database_name = database_name
         self._access_cookie_name = access_cookie_name
         self._refresh_cookie_name = refresh_cookie_name
         self._private_key = private_key
@@ -124,7 +118,7 @@ class Authentication(authx):
         self._social_providers = social_providers
         self._social_creds = social_creds
 
-        self._database_backend = MongoDBBackend(self._database_name)
+        self._database_backend = database_backend
         self._cache_backend = RedisBackend()
 
         self._auth_backend = JWTBackend(
@@ -200,8 +194,5 @@ class Authentication(authx):
     def search_router(self) -> APIRouter:
         return get_search_router(self._users_repo, self.admin_required)
 
-    def set_database(self, database_client: AsyncIOMotorClient) -> None:
-        self._database_backend.set_client(database_client)
-
     def set_cache(self, cache_client: Redis) -> None:
         self._cache_backend.set_client(cache_client)
